@@ -891,7 +891,6 @@ names.IPv6r <- function(x) ip.get.id(x)
 ##
 ##
 ##
-##
 setMethod(
   "=="
   ## 
@@ -903,7 +902,6 @@ setMethod(
 ##
 ##
 ##
-##
 setMethod(
   "!="
   ## 
@@ -915,7 +913,6 @@ setMethod(
 ##
 ##
 ##
-##
 setMethod(
   "<"
   ## 
@@ -927,7 +924,6 @@ setMethod(
 ##
 ##
 ##
-##
 setMethod(
   "<="
   ## 
@@ -939,7 +935,6 @@ setMethod(
 ##
 ##
 ##
-##
 setMethod(
   ">"
   ## 
@@ -951,7 +946,6 @@ setMethod(
 ##
 ##
 ##
-##
 setMethod(
   ">="
   ## 
@@ -959,7 +953,8 @@ setMethod(
   , function(e1,e2){
     if( IP_AVX2 ) .Call("Rip_ipv6_op2_bool_ge_2", e1, e2 ) else .Call("Rip_ipv6_op2_bool_ge_0", e1, e2 )
   }
-)##________________________________________________________________________________________________________________________
+)
+##________________________________________________________________________________________________________________________
 ##
 ##
 ##
@@ -982,6 +977,50 @@ setMethod(
   }
 )
 ##
+##
+##
+setMethod(
+  "<"
+  ## 
+  , signature(e1 = "IPv6r", e2 = "IPv6r")
+  , function(e1,e2){
+    if( IP_AVX2 ) .Call("Rip_ipv6r_op2_bool_lt_2", e1, e2 ) else .Call("Rip_ipv6r_op2_bool_lt_0", e1, e2 )
+  }
+)
+##
+##
+##
+setMethod(
+  "<="
+  ## 
+  , signature(e1 = "IPv6r", e2 = "IPv6r")
+  , function(e1,e2){
+    if( IP_AVX2 ) .Call("Rip_ipv6r_op2_bool_le_2", e1, e2 ) else .Call("Rip_ipv6r_op2_bool_le_0", e1, e2 )
+  }
+)
+##
+##
+##
+setMethod(
+  ">"
+  ## 
+  , signature(e1 = "IPv6r", e2 = "IPv6r")
+  , function(e1,e2){
+    if( IP_AVX2 ) .Call("Rip_ipv6r_op2_bool_gt_2", e1, e2 ) else .Call("Rip_ipv6r_op2_bool_gt_0", e1, e2 )
+  }
+)
+##
+##
+##
+setMethod(
+  ">="
+  ## 
+  , signature(e1 = "IPv6r", e2 = "IPv6r")
+  , function(e1,e2){
+    if( IP_AVX2 ) .Call("Rip_ipv6r_op2_bool_ge_2", e1, e2 ) else .Call("Rip_ipv6r_op2_bool_ge_0", e1, e2 )
+  }
+)
+##
 ## ? IPv6-IP
 ##
 ##________________________________________________________________________________________________________________________
